/-style substring filter applied to the left list.
Structs
- Filter
- Less/vim-style
/filter applied to the left list. WhenModal::FilterEditis active the input strip is open and printable keys are routed to it; when not, the filter is “applied” — rows still hidden, but the strip shows the static badge.